set more off
set linesize 150
cd "H:\CRUE\Stata\Datasources"
use FGH_2022_COHORT_GEN_EX.dta, replace
capture log close
log using "FGH_ANALYSIS_2022_Results_GEN_EX.log", replace 

********************************************************************************
*******************************     Limit Sample    ****************************
********************************************************************************

foreach x in belong fgh01 oncampus01 homevisits timestuorg firstgencomp01{
	codebook `x'
}

drop if belong==. | timestuorg==. | homevisits==.
drop if fgh01==0 & firstgencomp01==0


********************************************************************************
***********************     Descritpive Statistics      ************************
********************************************************************************

tabulate belong


********************************************************************************
**************************     Empty Means Models    ***************************
********************************************************************************

display "STATA Empty Model Predicting Ordinal Belong"
	gologit2 belong, pl nolog 
	display "-2LL= " e(ll)*-2 // Print -2LL for model
	estat ic, n(931) // AIC and BIC using N=931
	margins // all 3 probabilities

	
********************************************************************************
*********************     Proportional Odds - FGH Model   **********************
********************************************************************************

display "STATA Proportional Odds Model Predicting Ordinal Belong from FGH Participation"
	gologit2 belong fgh01, pl nolog 
	display "-2LL= " e(ll)*-2 // Print -2LL for model
	estat ic, n(931) // AIC and BIC using N=931


********************************************************************************
******************     Proportional Odds - 4 Predictor Model    ****************
********************************************************************************

display "STATA Proportional Odds Model Predicting Ordinal Belong"
	gologit2 belong fgh01 oncampus01 homevisits timestuorg, pl nolog 
	display "-2LL= " e(ll)*-2 // Print -2LL for model
	estat ic, n(931) // AIC and BIC using N=931

	margins, at(c.fgh01=(0(1)1) c.oncampus01=(0(1)1) c.timestuorg=(1(2)5)) predict(xb) // Yhat>0 in logits
	marginsplot, xdimension(c.timestuorg) noci  // graph of Yhat>0 in logits
	
display "Get Odds Ratios Instead of Logit Fixed Effects"
	gologit2 belong fgh01 oncampus01 homevisits timestuorg, pl or nolog

	
********************************************************************************
***********     TEST - Non-Proportional Odds - 4 Predictor Model    ************
********************************************************************************

display "TEST - STATA Non-Proportional Odds Model Predicting Ordinal Belong"
display "TEST - all 4 predictor slopes not significantly different across submodels"
	gologit2 belong fgh01 oncampus01 homevisits timestuorg, gamma nolog
	display "-2LL= " e(ll)*-2 // Print -2LL for model
	estat ic, n(931) // AIC and BIC using N=931
	
	
log close
