set more off
set linesize 150
cd "H:\CRUE\Stata\Datasources"
clear

********************************************************************************
***************************   Import Files   ***********************************
********************************************************************************


// import and save E@I data as a .dta file

	import excel "E@I Fall 2022 results.xlsx", firstrow clear case(lower)
	save "Fall 2022 ExcellingatIowa.dta", replace

// import fall 2022 cohort data 

	import excel "Fall 2022 FGH Cohort Data Update_4.6.23.xlsx", firstrow clear case(lower)

// merge E@I file with fall 2022 cohort data

	merge 1:1 universityid using "Fall 2022 ExcellingatIowa.dta"
	drop if _merge==2  // these are new transfer students who take E@I
	drop _merge
	save "FGH_2022_COHORT_2022_GEN_EX.dta", replace
	clear

	
	
// if you don't need to merge, this command loads the most recent merged files

	use "FGH_2022_DATA_SP23.dta", replace

	
	
********************************************************************************
***********************   Drop Unnecessary Columns   ***************************
********************************************************************************


// drop text variables, redundant variables, or variables we don't need
	drop masterid  hsunitalgebraitotal hsunitalgebraiitotal hsunitgeometrytotal hsunithighermathtotal hsunitbiologytotal hsunitchemistrytotal hsunitphysicstotal hsunitothersciencetotal trio campusstatus completiontime displayname lastname firstname masterid sessionadded email hawkid admcode advisorname numreferrals numnotes __0770likemost __0780likeleast __0800expectationnotmet __0790expectationmet __0801undergradgoal __0750champion __0700transitionprogramsfir __0870transferdifficulty __0700transitionprogramsfir __0710choose1 __0720choose2 __0813micreason __0812mostinterestingcourse __0810mdc __0811mdcbehavior __0820mdcuniversity includedinoriginalpull


// drop students who are less than full-time
	drop if officialcohort=="Not Official Cohort"

	

********************************************************************************
*************************   Clean Demographics   *******************************
********************************************************************************


//--------------------------------------------------------------- SEX and GENDER


// sex and gender variables are categorical variables; the following code creates dummy codes for gender; due to small sample sizes in the analyses for transgender, nonbinary, and no gender disclosed, these three variables were also grouped into another gender dummy variable; original variables are retained
		
	codebook genderidentity sex, all
	rename genderidentity gender
	tab gender sex, missing

	replace sex="Prefer not to answer" if sex==""

	gen man01=0
	replace man01=1 if sex=="Male" & gender=="(null)"
	replace man01=1 if sex=="Male" & gender=="CISGENDER"
	replace man01=1 if sex=="Male" & gender=="NO_ANSWER"
	replace man01=1 if gender=="CISGENDER,MAN"
	replace man01=1 if gender=="MAN"
	replace man01=1 if gender=="MAN,TRANSGENDER"
	label variable man01 "Identify as Man: 0=no, 1=yes"
	label define labelman01 0 "Not Man" 1 "Man"
	label values man01 labelman01
	tab gender man01
	tab sex man01
	tab gender man01

	gen woman01=0
	replace woman01=1 if sex=="Female" & gender=="(null)"
	replace woman01=1 if sex=="Female" & gender=="CISGENDER"
	replace woman01=1 if sex=="Female" & gender=="NO_ANSWER"
	replace woman01=1 if gender=="CISGENDER,WOMAN"
	replace woman01=1 if gender=="TRANSGENDER,WOMAN"
	replace woman01=1 if gender=="WOMAN"
	label variable woman01 "Identify as Woman: 0=no, 1=yes"
	label define labelwoman01 0 "Not Woman" 1 "Woman"
	label values woman01 labelwoman01
	tab gender woman01

	gen nonbinary01=0
	replace nonbinary01=1 if gender=="AGENDER"
	replace nonbinary01=1 if gender=="AGENDER,ANOTHER_GENDER"
	replace nonbinary01=1 if gender=="AGENDER,ANOTHER_GENDER,NON_BINARY"
	replace nonbinary01=1 if gender=="AGENDER,ANOTHER_GENDER,CISGENDER,MAN,NON_BINARY,TRANSGENDER,WOMAN"
	replace nonbinary01=1 if gender=="AGENDER,NON_BINARY"
	replace nonbinary01=1 if gender=="AGENDER,TRANSGENDER"
	replace nonbinary01=1 if gender=="ANOTHER_GENDER"
	replace nonbinary01=1 if gender=="ANOTHER_GENDER,MAN,NON_BINARY,TRANSGENDER"
	replace nonbinary01=1 if gender=="ANOTHER_GENDER,NON_BINARY"
	replace nonbinary01=1 if gender=="ANOTHER_GENDER,NON_BINARY,TRANSGENDER"
	replace nonbinary01=1 if gender=="CISGENDER,NON_BINARY"
	replace nonbinary01=1 if gender=="CISGENDER,NON_BINARY,TRANSGENDER"
	replace nonbinary01=1 if gender=="CISGENDER,NON_BINARY,WOMAN"
	replace nonbinary01=1 if gender=="MAN,NON_BINARY"
	replace nonbinary01=1 if gender=="MAN,NON_BINARY,TRANSGENDER"
	replace nonbinary01=1 if gender=="MAN,NON_BINARY,WOMAN"
	replace nonbinary01=1 if gender=="NON_BINARY"
	replace nonbinary01=1 if gender=="NON_BINARY,TRANSGENDER"
	replace nonbinary01=1 if gender=="NON_BINARY,TRANSGENDER,WOMAN"
	replace nonbinary01=1 if gender=="NON_BINARY,WOMAN"
	label variable nonbinary01 "Idenitfy as Non-Binary: 0=no, 1=yes"
	label define labelnonbinary01 0 "Not Non-Binary" 1 "Non-Binary"
	label values nonbinary01 labelnonbinary01
	tab nonbinary01

	gen transgender01=0
	replace transgender01=1 if gender=="MAN,TRANSGENDER"
	replace transgender01=1 if gender=="TRANSGENDER"
	replace transgender01=1 if gender=="TRANSGENDER,WOMAN"
	label variable transgender01 "Identify as Transgender: 0=no, 1=yes"
	label define labeltransgender01 0 "Not Transgender" 1 "Transgender"
	label values transgender01 labeltransgender01
	tab transgender01

	gen nogenderdisclosed01=0
	replace	nogenderdisclosed01=1 if sex=="Prefer not to answer" & gender=="(null)"
	replace	nogenderdisclosed01=1 if sex=="" & gender=="(null)"
	replace nogenderdisclosed01=1 if gender=="NO_ANSWER" & sex=="Prefer not to answer"
	label variable nogenderdisclosed01 "Did not disclose Gender: 0=no, 1=yes"
	label define labelnogenderdisclosed01 0 "Disclosed Gender" 1 "Did not disclose Gender"
	label values nogenderdisclosed01 labelnogenderdisclosed01
	tab nogenderdisclosed01

	//group nonbinary01, transgender01, and didnt disclose into "another gender identity"

	gen anothergender01=0
	replace anothergender01=1 if nonbinary01==1 & man01==0 & woman01==0
	replace anothergender01=1 if transgender01==1 & man01==0 & woman01==0
	replace anothergender01=1 if nogenderdisclosed01==1 & man01==0 & woman01==0
	label variable anothergender01 "Gender other than man/woman: 0=no, 1=yes"
	label define labelanothergender01 0 "Man or Woman" 1 "Another Gender"
	label values anothergender01 labelanothergender01
	tab nogenderdisclosed01

	tab man01 woman01, missing
	tab anothergender01


//--------------------------------------------------------------- RACE/ETHNICITY

// ethnicity is a categorical variable that aligns with IPEDS definitions of race/ethnicity; the following code creates dummy codes for race/ethnicity; due to small sample sizes in the analyses, black, native, latinae, multiracial, pacific, were also grouped into an underrepresented minority dummy variable; native, pacific, and unknown are also grouped into "another race/ethnicity"; original ethnicity variable is retained

	rename fedreportedethnicitydescr ethnicity
	codebook ethnicity
	tab ethnicity, missing

	gen black01=0
	replace black01=1 if ethnicity=="African American or Black"
	label variable black01 "Black: 0=no, 1=yes"
	label define labelblack01 0 "Not Black" 1 "Black"
	label values black01 labelblack01

	gen nativeamerican01=0
	replace nativeamerican01=1 if ethnicity=="Alaskan Native or American Indian"
	label variable nativeamerican01 "Native American: 0=no, 1=yes"
	label define labelnativeamerican01 0 "Not Native American" 1 "Native American"
	label values nativeamerican01 labelnativeamerican01

	gen asian01=0
	replace asian01=1 if ethnicity=="Asian"
	label variable asian01 "Asian: 0=no, 1=yes"
	label define labelasian01 0 "Not Asian" 1 "Asian"
	label values asian01 labelasian01

	gen latinae01=0
	replace latinae01=1 if ethnicity=="Hispanic or Latino(a)"
	label variable latinae01 "Latinae: 0=no, 1=yes"
	label define labellatinae01 0 "Not Latinae" 1 "Latinae"
	label values latinae01 labellatinae01

	gen multiracial01=0
	replace multiracial01=1 if ethnicity=="Multi-Racial"
	label variable multiracial01 "Multi-Racial: 0=no, 1=yes"
	label define labelmultiracia01 0 "Not Multi-Racial" 1 "Multi-Racial"
	label values multiracial01 labelmultiracia01

	gen pacific01=0
	replace pacific01=1 if ethnicity=="Native Hawaiian or Other Pacific Islander"
	label variable pacific01 "Pacific Islander: 0=no, 1=yes"
	label define labelpacific01 0 "Not Pacific Islander" 1 "Pacific Islander"
	label values pacific01 labelpacific01

	gen internationalrace01=0
	replace internationalrace01=1 if ethnicity=="Nonresident Alien"
	label variable internationalrace01 "International from Race Variable: 0=no, 1=yes"
	label define labelinterrace01 0 "Not International" 1 "International"
	label values internationalrace01 labelinterrace01

	gen raceunknown01=0
	replace raceunknown01=1 if ethnicity=="Race and Ethnicity unknown"
	label variable raceunknown01 "Unknown Race: 0=no, 1=yes"
	label define labelraceunknown01 0 "Race Not Unknown" 1 "Race Unknown"
	label values raceunknown01 labelraceunknown01

	gen white01=0
	replace white01=1 if ethnicity=="White, not of Hispanic or Latino(a) origin"
	label variable white01 "White: 0=no, 1=yes"
	label define labelwhite01 0 "Not White" 1 "White"
	label values white01 labelwhite01

	gen anotherrace01=0
	replace anotherrace01=1 if nativeamerican01==1
	replace anotherrace01=1 if pacific01==1
	replace anotherrace01=1 if raceunknown01==1
	label variable anotherrace01 "Another race: 0=no, 1=yes"
	label define labelanotherrace01 0 "Not Another race" 1 "Another race"
	label values anotherrace01 labelanotherrace01

	tab ethnicity black01
	tab ethnicity nativeamerican01
	tab ethnicity asian01
	tab ethnicity latinae01
	tab ethnicity multiracial01
	tab ethnicity pacific01
	tab ethnicity internationalrace01
	tab ethnicity raceunknown01
	tab ethnicity white01
	tab ethnicity anotherrace01


//------------------------------------------------------ FIRST GENERATION STATUS

	codebook firstgenstatus
	tab firstgenstatus, missing

	gen firstgen01=0
	replace firstgen01=1 if firstgenstatus=="First-Gen"
	label variable firstgen01 "First Generation: 0=no, 1=yes"
	label define labelfirstgen01 0 "Not First-Generation" 1 "First-Generation"
	label values firstgen01 labelfirstgen01
	tab firstgenstatus firstgen01, missing
	drop firstgenstatus
	order firstgen01, after(raceunknown01)


//-------------------------------------------------------------- LIVES ON-CAMPUS

	codebook onoffcampus
	tab onoffcampus

	gen oncampus01=0
	replace oncampus01=1 if onoffcampus=="ON_CAMPUS"
	label variable oncampus01 "Lives On-Campus: 0=no, 1=yes"
	label define labeloncampus01 0 "Off Campus" 1 "On Campus"
	label values oncampus01 labeloncampus01
	tab onoffcampus oncampus01
	drop onoffcampus
	order oncampus01, after(firstgen)


//---------------------------------------------------------------------- COLLEGE

	codebook curricularcollegeacadname
	drop college
	rename curricularcollegeacadname college

	gen clas01=.
	replace clas01=1 if college=="College of Liberal Arts and Sciences"
	replace clas01=0 if college!="College of Liberal Arts and Sciences"
	label variable clas01 "College: 1=CLAS, 0=not CLAS"
	label define labelclas 0 "Other College" 1 "CLAS"
	label values clas01 labelclas


********************************************************************************
*****************   Create Programs and Comparison Groups **********************
********************************************************************************


//----------------------------------------------------- IN FGH (drops withdraws)

	rename fghparticipant fghstudent
	codebook fghstudent

	gen fgh01=0
	replace fgh01=1 if fghstudent=="Y" | fghstudent=="FGH 20223"
	label variable fgh01 "In FGH at Census: 0=no, 1=yes"
	label define labelfgh 0 "No in FGH" 1 "In FGH"
	label values fgh01 labelfgh
	tab fghstudent fgh01

	drop fghstudent fghspringprogramtrack

//---------------------------------------------------------------------- IN TRIO
		
	drop trio
	rename triostatus trio
	codebook trio
	tab trio

	gen trio01=.
	replace trio01=0 if trio=="false"
	replace trio01=1 if trio=="true"
	label variable trio01 "In TRIO Program: 0=no, 1=yes"
	label define labeltrio01 0 "Not in TRIO" 1 "In TRIO"
	label values trio01 labeltrio01
	tab trio trio01
	drop trio
	order trio01, after(firstgen)

//--------------------------------------------------------------- FGH COMPARISON

	gen firstgencomp01=0
	replace firstgencomp01=1 if firstgen01==1
	replace firstgencomp01=0 if trio01==1
	replace firstgencomp01=0 if fgh01==1
	
	label variable firstgencomp01 "First Gen not in Any Program: 0=no, 1=yes"
	label define labelfirstgencomp01 0 "Not in FGH Comparison Group" 1 "In FGH Comparison Group"
	label values firstgencomp01 labelfirstgencomp01
	order firstgencomp01, after(fgh01)


********************************************************************************
************   Convert Academic Performance to Numeric and Binary   ************
********************************************************************************

//--------------------------------------------------------- RENAME CREDIT FIELDS

	rename fa22censustermattemptedcredits fa22attemptcred 
	rename fa22censuscumattemptedcredits fa22attemptcredcum
	rename fa22finaltermearnedcredits fa22earnedcred
	rename finalcumearnedcredits fa22earnedcredcum
	rename cumsapuiattemptedhourssp23 sp23attemptcredcum
	rename sp23termcensusattemptedcredits sp23attemptcred
	rename cumoverallearnedhourssp23 sp23earnedcredcum
	//	rename sp23earnedcred	

	replace fa22attemptcred="" if fa22attemptcred=="(null)"
	replace fa22attemptcredcum="" if fa22attemptcredcum=="(null)"
	replace fa22earnedcred="" if fa22earnedcred=="(null)"
	replace sp23attemptcred="" if sp23attemptcred=="Not Enrolled"
	destring fa22attemptcred, replace
	destring fa22attemptcredcum, replace
	destring fa22earnedcred, replace
	destring sp23attemptcred, replace

	replace fa22attemptcred=0 if fa22attemptcred==.
	replace fa22attemptcredcum=0 if fa22attemptcredcum==.
	replace fa22earnedcred=0 if fa22earnedcred==.
	replace	fa22earnedcredcum=0 if fa22earnedcredcum==.

	replace sp23attemptcred=0 if sp23attemptcred==.
	replace sp23attemptcredcum=0 if sp23attemptcredcum==.
	replace sp23earnedcred=0 if sp23earnedcred==.
	replace	sp23earnedcredcum=0 if sp23earnedcredcum==.


//--------------------------------------------------------------------- TERM GPA

	tab fa22termgpa
	rename fa22termgpa fa22gpa

	replace fa22gpa="" if fa22gpa=="(null)"
	destring fa22gpa, replace
	label variable fa22gpa "Numeric Fall 2022 Term GPA"

	rename cumulativegpa fa22gpacum
	label variable fa22gpacum "Numeric Fall 2022 Cumulative GPA"

	rename termuigradedgpasp23 sp23gpa
	label variable sp23gpa "Numeric Spring 2023 Term GPA"
		
	rename cumoverallgradedgpasp23 sp23gpacum
	drop cumuigradedgpasp23
	label variable sp23gpacum "Numeric Spring 2023 Cumulative GPA"



//--------------------------------------------------------- WITHDREW DURING TERM

	gen fa22withdrew01=0
	replace fa22withdrew01=1 if withdrawal=="WITHDRAWN"
	label variable fa22withdrew01 "Withdrew during Fall 2022 Term: 0=no, 1=yes"
	label define labelwithdrew 0 "Did not Withdraw" 1 "Withdrew"
	label values fa22withdrew01 labelwithdrew
	drop withdrawal

	gen sp23withdrew01=0
	replace sp23withdrew01=1 if enrollmentstatussp23=="WITHDRAWN"
	label variable sp23withdrew01 "Withdrew during Spring 2023 Term: 0=no, 1=yes"
	label values sp23withdrew01 labelwithdrew
	drop enrollstatussp23 enrollmentstatussp23


//-------------------------------------------------------------------- PROBATION

	gen fa22probation01=0
	replace fa22probation01=1 if probation=="Y"
	label variable fa22probation01 "On Probation After Fall 2022 Term: 0=no, 1=yes"
	label values fa22probation01 labelprobation
	drop probation
	order fa22probation01, after(fa22withdrew01)

	gen sp23probation01=0
	replace sp23probation01=1 if isonprobationsp23=="Y"
	label variable sp23probation01 "On Probation After Spring 2023 Term: 0=no, 1=yes"
	drop isonprobationsp23
	order sp23probation01, after(sp23withdrew01)




//------------------------------------------------------------------- DEANS LIST

	gen fa22deanslist01=0
	replace fa22deanslist01=1 if deanslist=="Y"
	label variable fa22deanslist01 "On Deanslist After Fall 2022 Term: 0=no, 1=yes"
	label values fa22deanslist01 labeldeanslist
	drop deanslist
	order fa22deanslist01, after(fa22probation01)

	gen sp23deanslist01=0
	replace sp23deanslist01=1 if isdeanslistsp23=="Y"
	label variable sp23deanslist01 "On Deanslist After Spring 2023 Term: 0=no, 1=yes"
	label values sp23deanslist01 labeldeanslist
	drop isdeanslistsp23
	order sp23deanslist01, after(sp23probation01)
	


//----------------------------------------------------------------------- HONORS

	gen fa22honors01=0
	replace fa22honors01=1 if ishonors=="Y"
	label variable fa22honors01 "Honors during Fall 2022 Term: 0=no, 1=yes"
	label values fa22honors01 labelhonors
	drop ishonors honors
	order fa22honors01, after(fa22deanslist01)


	gen sp23honors01=0
	replace sp23honors01=1 if ishonorssp23=="Y"
	label variable sp23honors01 "Honors during Spring 2023 Term: 0=no, 1=yes"
	label values sp23honors01 labelhonors
	drop ishonorssp23
	order sp23honors01, after(sp23deanslist01)
	
********************************************************************************
**************************   Create E@I Indices   ******************************
********************************************************************************

	gen belong=__0030belong
	recode belong (1=0) (2=0) (3=0) (4=0) (5=1) (6=1) (7=2)
	label variable belong "Level of belonging on campus: 0=no, 1=some, 2=high"
	label define labelbelong 0 "Low belonging" 1 "Some belonging" 2 "High belonging"
	label values belong labelbelong
	
	gen homevisits=__0090returnedhome
	label variable homevisits "Number of visits to home student made"
	gen timestuorg=__0360involvement
	label variable timestuorg "Number of hours spent per week with a student or community organization"
	

********************************************************************************
***************************   Reorder Variables   ******************************
********************************************************************************

// keeps variables for the FGH ordinal example from 2024 generalized linear models
	keep man01 woman01 anothergender01 black01 asian01 latinae01 multiracial01 anotherrace01 oncampus01 clas fgh01 firstgencomp01 homevisits timestuorg belong
	order belong fgh01 man01 woman01 anothergender01 black01 asian01 latinae01 multiracial01 anotherrace01 oncampus01 clas homevisits timestuorg firstgencomp01


********************************************************************************
*************************   Export Cleaned Dataset   ***************************
********************************************************************************


save "FGH_2022_COHORT_GEN_EX.dta", replace


// export excel using "$filesave\FGH_CLEAN_EXCEL_RESULTS_2022_COHORT_GEN_EX.xlsx", firstrow(variables) replace